package Bencher::ScenarioR::LoggingModules::NullLogging;

our $VERSION = 0.002; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors => 0.0018,
        participant => "Log::Dispatch::Null-100k_debug",
        rate => 0.6,
        samples => 6,
        time => 1.7,
        vs_slowest => 1,
      },
      {
        errors => 0.004,
        participant => "Log::Contextual+Log4perl-100k_trace",
        rate => 1.5,
        samples => 7,
        time => 0.66,
        vs_slowest => 2.5,
      },
      {
        errors => 0.0012,
        participant => "Log::Contextual+SimpleLogger-100k_trace",
        rate => 1.6,
        samples => 6,
        time => 0.63,
        vs_slowest => 2.6,
      },
      {
        errors => 0.0068,
        participant => "Mojo::Log-100k_debug",
        rate => 3,
        samples => 7,
        time => 0.3,
        vs_slowest => 5,
      },
      {
        errors => 0.00047,
        participant => "Log::Dispatchouli-100k_debug",
        rate => 4.9,
        samples => 7,
        time => 0.2,
        vs_slowest => 8.2,
      },
      {
        errors => 0.00014,
        participant => "Log::Log4perl::Tiny-100k_trace",
        rate => 7.5,
        samples => 6,
        time => 0.13,
        vs_slowest => 13,
      },
      {
        errors => 0.0002,
        participant => "Log::Mini-100k_trace",
        rate => 11,
        samples => 6,
        time => 0.088,
        vs_slowest => 19,
      },
      {
        errors => 0.00028,
        participant => "Log::Any-null_adapter-100k_log_trace",
        rate => 13,
        samples => 6,
        time => 0.078,
        vs_slowest => 22,
      },
      {
        errors => 0.00027,
        participant => "Log::Log4perl-easy-100k_trace",
        rate => 15,
        samples => 7,
        time => 0.066,
        vs_slowest => 25,
      },
      {
        errors => 0.00092,
        participant => "Log::Fast-100k_DEBUG",
        rate => 20,
        samples => 7,
        time => 0.05,
        vs_slowest => 30,
      },
      {
        errors => 4e-05,
        participant => "Log::Any-no_adapter-100k_log_trace",
        rate => 35,
        samples => 6,
        time => 0.029,
        vs_slowest => 58,
      },
      {
        errors => 0.00069,
        participant => "Log::ger+LGP:OptAway-100k_log_trace",
        rate => 40,
        samples => 7,
        time => 0.02,
        vs_slowest => 70,
      },
      {
        errors => 9.9e-05,
        participant => "Log::ger-100k_log_trace",
        rate => 51,
        samples => 6,
        time => 0.019,
        vs_slowest => 86,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "LoggingModules::NullLogging",
                                          },
      "func.bencher_version"           => undef,
      "func.code_startup"              => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => "2671.630",
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 3143.896,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2906.817,
                                              stepping                     => 7,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "lahf_lm",
                                                                                "epb",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "xsaveopt",
                                                                                "dtherm",
                                                                                "ida",
                                                                                "arat",
                                                                                "pln",
                                                                                "pts",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 42,
                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                              number_of_cores              => 4,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 2820.538,
                                              stepping                     => 7,
                                            },
                                          ],
      "func.elapsed_time"              => 33.2853660583496,
      "func.module_startup"            => undef,
      "func.module_versions"           => {
                                            "__PACKAGE__"                                    => 1.041,
                                            "Bencher::Scenario::LoggingModules::NullLogging" => undef,
                                            "Benchmark::Dumb"                                => 0.111,
                                            "Devel::Platform::Info"                          => 0.16,
                                            "Log::Any"                                       => 1.707,
                                            "Log::Contextual"                                => 0.007001,
                                            "Log::Dispatch::Null"                            => 2.65,
                                            "Log::Dispatchouli"                              => 2.015,
                                            "Log::Fast"                                      => "v2.0.0",
                                            "Log::ger"                                       => 0.025,
                                            "Log::ger::Plugin::OptAway"                      => 0.006,
                                            "Log::Log4perl"                                  => 1.49,
                                            "Log::Log4perl::Tiny"                            => "1.4.0",
                                            "Log::Mini"                                      => "0.0.1",
                                            "Mojo::Log"                                      => undef,
                                            "perl"                                           => "v5.26.0",
                                            "Sys::Info"                                      => 0.78,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 12]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "sonya",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-4.8.0-53-generic",
                                            kname    => "Linux",
                                            kvers    => "4.8.0-53-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 18.2,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "4.8.0-53-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 6,
      "func.scenario_module"           => "Bencher::Scenario::LoggingModules::NullLogging",
      "func.scenario_module_md5sum"    => "812970db708f76d7df268a0df49ad8f7",
      "func.scenario_module_mtime"     => 1550803999,
      "func.scenario_module_sha1sum"   => "f162e27da75bceaedd54a549ac92dc1c8eb2663f",
      "func.scenario_module_sha256sum" => "924672f9025f17ddda92f616da4cd82a6e518f6788c616345f02571f3dbb3c2d",
      "func.time_end"                  => 1550804550.87089,
      "func.time_factor"               => 1,
      "func.time_start"                => 1550804517.58553,
      "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
      "table.field_units"              => [undef, undef, "/s"],
      "table.fields"                   => [
                                            "participant",
                                            "dataset",
                                            "rate",
                                            "time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Benchmark logging statement that does not output anywhere (to measure logging overhead)

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

